@@ -26,7 +26,13 @@ modelLookup <- function(model = NULL)
             ## fda
             'fda', 'fda', 
             ## foba
-            'foba', 'foba', 
+            'foba', 'foba',
+            ## gam
+            'gam', 'gam',
+            ## gamLoess
+            'gamLoess', 'gamLoess',
+            ## gamSpline
+            'gamSpline',
             ## gamboost
             'gamboost', 'gamboost', 
             ## GAMens
@@ -231,7 +237,13 @@ modelLookup <- function(model = NULL)
               ## fda
               'nprune', 'degree', 
               ## foba
-              'k', 'lambda', 
+              'k', 'lambda',
+              ## gam
+              'select', 'method',
+              ## gamLoess
+              'span', 'degree',
+              ## gamSpline
+              'df',
               ## gamboost
               'mstop', 'prune', 
               ## GAMens
@@ -448,6 +460,12 @@ modelLookup <- function(model = NULL)
               ## foba
               '#Variables Retained',
               'L2 Penalty',
+              ## gam
+              'Feature Selection', 'Method',
+              ## gamLoess
+              'Span', 'Degree',
+              ## gamSpline
+              'Degrees of Freedom',
               ## gamboost
               '# Boosting Iterations',
               'AIC Prune?',
@@ -695,7 +713,13 @@ modelLookup <- function(model = NULL)
              ## fda
              FALSE, FALSE, 
              ## foba
-             TRUE, FALSE, 
+             TRUE, FALSE,
+             ## gam
+             FALSE, FALSE,
+             ## gamLoess
+             FALSE, FALSE,
+             ## gamSpline
+             FALSE,
              ## gamboost
              TRUE, FALSE, 
              ## GAMens
@@ -899,7 +923,13 @@ modelLookup <- function(model = NULL)
                 ## fda
                 FALSE, FALSE, 
                 ## foba
-                TRUE, TRUE, 
+                TRUE, TRUE,
+                ## gam
+                TRUE, TRUE,
+                ## gamLoess
+                TRUE, TRUE,
+                ## gamSpline
+                TRUE,
                 ## gamboost
                 TRUE, TRUE, 
                 ## GAMens
@@ -1104,7 +1134,13 @@ modelLookup <- function(model = NULL)
                   ## fda
                   TRUE, TRUE, 
                   ## foba
-                  FALSE, FALSE, 
+                  FALSE, FALSE,
+                  ## gam
+                  TRUE, TRUE,
+                  ## gamLoess
+                  TRUE, TRUE,
+                  ## gamSpline
+                  TRUE,
                   ## gamboost
                   TRUE, TRUE, 
                   ## GAMens
@@ -1309,7 +1345,13 @@ modelLookup <- function(model = NULL)
                     ## fda
                     TRUE, TRUE, 
                     ## foba
-                    FALSE, FALSE, 
+                    FALSE, FALSE,
+                    ## gam
+                    TRUE, TRUE,
+                    ## gamLoess
+                    TRUE, TRUE,
+                    ## gamSpline
+                    TRUE,
                     ## gamboost
                     TRUE, TRUE, 
                     ## GAMens
