@@ -158,6 +158,9 @@ byComplexity <- function(x, model)
            glmnet = x[order(-x$lambda, x$alpha),],
            stepLDA =, stepQDA = x[order(x$maxvar),],
            GAMens = x[order(x$iter, x$rsm_size),],
+           gam = x[order(x$select),],
+           gamLoess =  x[order(x$degree, -x$span),],
+           gamSpline =  x[order(x$df),],
            stop("no sorting routine for this model")
            )
 
